.. _slam:

SLaM Pipelines
==============

The Source, Lens and Mass **(SLaM)** analysis pipelines allow one to fit large lens samples with a variety of source,
light and mass profiles in a manageable and structured way.

The readthedocs overview for **SLaM** is not written yet. However, checkout
`this link <https://github.com/Jammy2211/autolens_workspace/blob/release/notebooks/imaging/chaining/slam/light_parametric__mass_total__source_parametric.ipynb>`_
for a description of a **SLaM** analysis.